@@ -1,8 +1,10 @@
 ###################################################
 ### chunk number 1: setup
 ###################################################
+#line 183 "Ch_analysing_longitudinal_dataII.Rnw"
 rm(list = ls())
 if (!file.exists("tables")) dir.create("tables")
+if (!file.exists("figures")) dir.create("figures")
 set.seed(290875)
 options(prompt = "R> ", continue = "+  ",
     width = 63, # digits = 4,
@@ -41,12 +43,14 @@ setHook(packageEvent("lattice", "attach"), function(...) {
 ###################################################
 ### chunk number 2: singlebook
 ###################################################
+#line 222 "Ch_analysing_longitudinal_dataII.Rnw"
 book <- FALSE
 
 
 ###################################################
 ### chunk number 3: setup
 ###################################################
+#line 225 "Ch_analysing_longitudinal_dataII.Rnw"
 options(digits = 3)
 if (!interactive()) {
 print.summary.gee <- function (x, digits = NULL, quote = FALSE, prefix = "", ...)
@@ -80,12 +84,14 @@ print.summary.gee <- function (x, digits = NULL, quote = FALSE, prefix = "", ...
 ###################################################
 ### chunk number 4: ALDII-gee
 ###################################################
+#line 265 "Ch_analysing_longitudinal_dataII.Rnw"
 library("gee")
 
 
 ###################################################
 ### chunk number 5: ALDII-BtheB-data
 ###################################################
+#line 279 "Ch_analysing_longitudinal_dataII.Rnw"
 data("BtheB", package = "HSAUR2")
 BtheB$subject <- factor(rownames(BtheB))
 nobs <- nrow(BtheB)
@@ -99,6 +105,7 @@ names(BtheB_long)[names(BtheB_long) == "treatment"] <- "trt"
 ###################################################
 ### chunk number 6: ALDII-BtheB-geefit-indep
 ###################################################
+#line 289 "Ch_analysing_longitudinal_dataII.Rnw"
 osub <- order(as.integer(BtheB_long$subject))
 BtheB_long <- BtheB_long[osub,]
 btb_gee <- gee(bdi ~ bdi.pre + trt + length + drug,
@@ -109,6 +116,7 @@ btb_gee <- gee(bdi ~ bdi.pre + trt + length + drug,
 ###################################################
 ### chunk number 7: ALDII-BtheB-geefit-ex
 ###################################################
+#line 297 "Ch_analysing_longitudinal_dataII.Rnw"
 btb_gee1 <- gee(bdi ~ bdi.pre + trt + length + drug,
     data = BtheB_long, id = subject, family = gaussian,
     corstr = "exchangeable")
@@ -117,18 +125,21 @@ btb_gee1 <- gee(bdi ~ bdi.pre + trt + length + drug,
 ###################################################
 ### chunk number 8: ALDII-BtheB-geesummary
 ###################################################
+#line 309 "Ch_analysing_longitudinal_dataII.Rnw"
 summary(btb_gee)
 
 
 ###################################################
 ### chunk number 9: ALDII-BtheB-gee1summary
 ###################################################
+#line 317 "Ch_analysing_longitudinal_dataII.Rnw"
 summary(btb_gee1)
 
 
 ###################################################
 ### chunk number 10: ALDII-respiratory-data
 ###################################################
+#line 326 "Ch_analysing_longitudinal_dataII.Rnw"
 data("respiratory", package = "HSAUR2")
 resp <- subset(respiratory, month > "0")
 resp$baseline <- rep(subset(respiratory, month == "0")$status,
@@ -140,6 +151,7 @@ resp$month <- resp$month[, drop = TRUE]
 ###################################################
 ### chunk number 11: ALDII-respiratory-names
 ###################################################
+#line 334 "Ch_analysing_longitudinal_dataII.Rnw"
 names(resp)[names(resp) == "treatment"] <- "trt"
 levels(resp$trt)[2] <- "trt"
 
@@ -147,6 +159,7 @@ levels(resp$trt)[2] <- "trt"
 ###################################################
 ### chunk number 12: ALDII-respiratory-fit
 ###################################################
+#line 342 "Ch_analysing_longitudinal_dataII.Rnw"
 resp_glm <- glm(status ~ centre + trt + gender + baseline
     + age, data = resp, family = "binomial")
 resp_gee1 <- gee(nstat ~ centre + trt + gender + baseline
@@ -162,24 +175,28 @@ resp_gee2 <- gee(nstat ~ centre + trt + gender + baseline
 ###################################################
 ### chunk number 13: ALDII-resp-glm-summary
 ###################################################
+#line 358 "Ch_analysing_longitudinal_dataII.Rnw"
 summary(resp_glm)
 
 
 ###################################################
 ### chunk number 14: ALDII-resp-gee1summary
 ###################################################
+#line 366 "Ch_analysing_longitudinal_dataII.Rnw"
 summary(resp_gee1)
 
 
 ###################################################
 ### chunk number 15: ALDII-resp-gee2-summary
 ###################################################
+#line 374 "Ch_analysing_longitudinal_dataII.Rnw"
 summary(resp_gee2)
 
 
 ###################################################
 ### chunk number 16: ALDII-resp-confint
 ###################################################
+#line 382 "Ch_analysing_longitudinal_dataII.Rnw"
 se <- summary(resp_gee2)$coefficients["trttrt",
                                       "Robust S.E."]
 coef(resp_gee2)["trttrt"] +
@@ -189,6 +206,7 @@ coef(resp_gee2)["trttrt"] +
 ###################################################
 ### chunk number 17: ALDII-resp-confint-exp
 ###################################################
+#line 393 "Ch_analysing_longitudinal_dataII.Rnw"
 exp(coef(resp_gee2)["trttrt"] +
     c(-1, 1) * se * qnorm(0.975))
 
@@ -196,6 +214,7 @@ exp(coef(resp_gee2)["trttrt"] +
 ###################################################
 ### chunk number 18: ALDII-epilepsy
 ###################################################
+#line 404 "Ch_analysing_longitudinal_dataII.Rnw"
 data("epilepsy", package = "HSAUR2")
 itp <- interaction(epilepsy$treatment, epilepsy$period)
 tapply(epilepsy$seizure.rate, itp, mean)
@@ -205,6 +224,7 @@ tapply(epilepsy$seizure.rate, itp, var)
 ###################################################
 ### chunk number 19: ALDII-plot1
 ###################################################
+#line 415 "Ch_analysing_longitudinal_dataII.Rnw"
 layout(matrix(1:2, nrow = 1))
 ylim <- range(epilepsy$seizure.rate)
 placebo <- subset(epilepsy, treatment == "placebo")
@@ -220,6 +240,7 @@ boxplot(seizure.rate ~ period, data = progabide,
 ###################################################
 ### chunk number 20: ALDII-plot2
 ###################################################
+#line 434 "Ch_analysing_longitudinal_dataII.Rnw"
 layout(matrix(1:2, nrow = 1))
 ylim <- range(log(epilepsy$seizure.rate + 1))
 boxplot(log(seizure.rate + 1) ~ period, data = placebo,
@@ -233,6 +254,7 @@ boxplot(log(seizure.rate + 1) ~ period, data = progabide,
 ###################################################
 ### chunk number 21: ALDII-epilepsy-gee
 ###################################################
+#line 454 "Ch_analysing_longitudinal_dataII.Rnw"
 per <- rep(log(2),nrow(epilepsy))
 epilepsy$period <- as.numeric(epilepsy$period)
 names(epilepsy)[names(epilepsy) == "treatment"] <- "trt"
@@ -252,30 +274,35 @@ epilepsy_gee3 <- gee(fm, data = epilepsy, family = "poisson",
 ###################################################
 ### chunk number 22: ALDII-espilepsy-glm-summary
 ###################################################
+#line 478 "Ch_analysing_longitudinal_dataII.Rnw"
 summary(epilepsy_glm)
 
 
 ###################################################
 ### chunk number 23: ALDII-espilepsy-gee1-summary
 ###################################################
+#line 486 "Ch_analysing_longitudinal_dataII.Rnw"
 summary(epilepsy_gee1)
 
 
 ###################################################
 ### chunk number 24: ALDII-espilepsy-gee2-summary
 ###################################################
+#line 494 "Ch_analysing_longitudinal_dataII.Rnw"
 summary(epilepsy_gee2)
 
 
 ###################################################
 ### chunk number 25: ALDII-espilepsy-gee3-summary
 ###################################################
+#line 502 "Ch_analysing_longitudinal_dataII.Rnw"
 summary(epilepsy_gee3)
 
 
 ###################################################
 ### chunk number 26: ALDII-respiratory-lmer
 ###################################################
+#line 520 "Ch_analysing_longitudinal_dataII.Rnw"
 library("lme4")
 resp_lmer <- lmer(status ~ baseline + month +
     trt + gender + age + centre + (1 | subject),
@@ -286,6 +313,7 @@ exp(fixef(resp_lmer))
 ###################################################
 ### chunk number 27: ALDII-resp-lmer-dirty
 ###################################################
+#line 546 "Ch_analysing_longitudinal_dataII.Rnw"
 su <- summary(resp_lmer)
 if (!interactive()) {
     summary <- function(x) {
@@ -300,6 +328,7 @@ if (!interactive()) {
 ###################################################
 ### chunk number 28: ALDII-resp-lmer-summary
 ###################################################
+#line 561 "Ch_analysing_longitudinal_dataII.Rnw"
 summary(resp_lmer)
 
 
