@@ -1,8 +1,10 @@
 ###################################################
 ### chunk number 1: setup
 ###################################################
+#line 182 "Ch_multiple_linear_regression.Rnw"
 rm(list = ls())
 if (!file.exists("tables")) dir.create("tables")
+if (!file.exists("figures")) dir.create("figures")
 set.seed(290875)
 options(prompt = "R> ", continue = "+  ",
     width = 63, # digits = 4,
@@ -41,12 +43,14 @@ setHook(packageEvent("lattice", "attach"), function(...) {
 ###################################################
 ### chunk number 2: singlebook
 ###################################################
+#line 221 "Ch_multiple_linear_regression.Rnw"
 book <- FALSE
 
 
 ###################################################
 ### chunk number 3: MLR-hubble-tab
 ###################################################
+#line 238 "Ch_multiple_linear_regression.Rnw"
 data("hubble", package = "gamair")
 names(hubble) <- c("galaxy", "velocity", "distance")
 toLatex(HSAURtable(hubble, package = "gamair"), pcol = 2,
@@ -57,6 +61,7 @@ toLatex(HSAURtable(hubble, package = "gamair"), pcol = 2,
 ###################################################
 ### chunk number 4: MLR-clouds-tab
 ###################################################
+#line 251 "Ch_multiple_linear_regression.Rnw"
 data("clouds", package = "HSAUR2")
 toLatex(HSAURtable(clouds), pcol = 1,
     caption = paste("Cloud seeding experiments in Florida -- see text for",
@@ -67,12 +72,14 @@ toLatex(HSAURtable(clouds), pcol = 1,
 ###################################################
 ### chunk number 5: MLR-hubble-plot
 ###################################################
+#line 313 "Ch_multiple_linear_regression.Rnw"
 plot(velocity ~ distance, data = hubble)
 
 
 ###################################################
 ### chunk number 6: MLR-hubble-beta1
 ###################################################
+#line 333 "Ch_multiple_linear_regression.Rnw"
 sum(hubble$distance * hubble$velocity) /
     sum(hubble$distance^2)
 
@@ -80,18 +87,21 @@ sum(hubble$distance * hubble$velocity) /
 ###################################################
 ### chunk number 7: MLR-hubble-lm
 ###################################################
+#line 338 "Ch_multiple_linear_regression.Rnw"
 hmod <- lm(velocity ~ distance - 1, data = hubble)
 
 
 ###################################################
 ### chunk number 8: MLR-hubble-lm
 ###################################################
+#line 343 "Ch_multiple_linear_regression.Rnw"
 coef(hmod)
 
 
 ###################################################
 ### chunk number 9: MLR-hubble-age
 ###################################################
+#line 361 "Ch_multiple_linear_regression.Rnw"
 Mpc <- 3.09 * 10^19
 ysec <- 60^2 * 24 * 365.25
 Mpcyear <- Mpc / ysec
@@ -101,6 +111,7 @@ Mpcyear <- Mpc / ysec
 ###################################################
 ### chunk number 10: MLR-hubble-lmplot
 ###################################################
+#line 370 "Ch_multiple_linear_regression.Rnw"
 layout(matrix(1:2, ncol = 2))
 plot(velocity ~ distance, data = hubble)
 abline(hmod)
@@ -110,6 +121,7 @@ plot(hmod, which = 1)
 ###################################################
 ### chunk number 11: MLR-clouds-boxplots
 ###################################################
+#line 389 "Ch_multiple_linear_regression.Rnw"
 data("clouds", package = "HSAUR2")
 layout(matrix(1:2, nrow = 2))
 bxpseeding <- boxplot(rainfall ~ seeding, data = clouds,
@@ -121,6 +133,7 @@ bxpecho <- boxplot(rainfall ~ echomotion, data = clouds,
 ###################################################
 ### chunk number 12: MLR-clouds-scatterplots
 ###################################################
+#line 402 "Ch_multiple_linear_regression.Rnw"
 layout(matrix(1:4, nrow = 2))
 plot(rainfall ~ time, data = clouds)
 plot(rainfall ~ cloudcover, data = clouds)
@@ -131,6 +144,7 @@ plot(rainfall ~ prewetness, data = clouds)
 ###################################################
 ### chunk number 13: MLR-clouds-outliers
 ###################################################
+#line 417 "Ch_multiple_linear_regression.Rnw"
 rownames(clouds)[clouds$rainfall %in% c(bxpseeding$out,
                                         bxpecho$out)]
 
@@ -138,6 +152,7 @@ rownames(clouds)[clouds$rainfall %in% c(bxpseeding$out,
 ###################################################
 ### chunk number 14: MLR-clouds-formula
 ###################################################
+#line 432 "Ch_multiple_linear_regression.Rnw"
 clouds_formula <- rainfall ~ seeding +
     seeding:(sne + cloudcover + prewetness + echomotion) +
     time
@@ -146,18 +161,21 @@ clouds_formula <- rainfall ~ seeding +
 ###################################################
 ### chunk number 15: MLR-clouds-modelmatrix
 ###################################################
+#line 438 "Ch_multiple_linear_regression.Rnw"
 Xstar <- model.matrix(clouds_formula, data = clouds)
 
 
 ###################################################
 ### chunk number 16: MLR-clouds-contrasts
 ###################################################
+#line 444 "Ch_multiple_linear_regression.Rnw"
 attr(Xstar, "contrasts")
 
 
 ###################################################
 ### chunk number 17: MLR-clouds-lm
 ###################################################
+#line 454 "Ch_multiple_linear_regression.Rnw"
 clouds_lm <- lm(clouds_formula, data = clouds)
 class(clouds_lm)
 
@@ -165,12 +183,14 @@ class(clouds_lm)
 ###################################################
 ### chunk number 18: MLR-clouds-summary
 ###################################################
+#line 467 "Ch_multiple_linear_regression.Rnw"
 summary(clouds_lm)
 
 
 ###################################################
 ### chunk number 19: MLR-clouds-coef
 ###################################################
+#line 473 "Ch_multiple_linear_regression.Rnw"
 betastar <- coef(clouds_lm)
 betastar
 
@@ -178,18 +198,21 @@ betastar
 ###################################################
 ### chunk number 20: MLR-clouds-vcov
 ###################################################
+#line 479 "Ch_multiple_linear_regression.Rnw"
 Vbetastar <- vcov(clouds_lm)
 
 
 ###################################################
 ### chunk number 21: MLR-clouds-sd
 ###################################################
+#line 484 "Ch_multiple_linear_regression.Rnw"
 sqrt(diag(Vbetastar))
 
 
 ###################################################
 ### chunk number 22: MLR-clouds-lmplot
 ###################################################
+#line 489 "Ch_multiple_linear_regression.Rnw"
 psymb <- as.numeric(clouds$seeding)
 plot(rainfall ~ sne, data = clouds, pch = psymb,
      xlab = "S-Ne criterion")
@@ -204,6 +227,7 @@ legend("topright", legend = c("No seeding", "Seeding"),
 ###################################################
 ### chunk number 23: MLR-clouds-residfitted
 ###################################################
+#line 508 "Ch_multiple_linear_regression.Rnw"
 clouds_resid <- residuals(clouds_lm)
 clouds_fitted <- fitted(clouds_lm)
 
@@ -211,6 +235,7 @@ clouds_fitted <- fitted(clouds_lm)
 ###################################################
 ### chunk number 24: MLR-clouds-residplot
 ###################################################
+#line 522 "Ch_multiple_linear_regression.Rnw"
 plot(clouds_fitted, clouds_resid, xlab = "Fitted values",
      ylab = "Residuals", type = "n",
      ylim = max(abs(clouds_resid)) * c(-1, 1))
@@ -221,6 +246,7 @@ text(clouds_fitted, clouds_resid, labels = rownames(clouds))
 ###################################################
 ### chunk number 25: MLR-clouds-qqplot
 ###################################################
+#line 535 "Ch_multiple_linear_regression.Rnw"
 qqnorm(clouds_resid, ylab = "Residuals")
 qqline(clouds_resid)
 
@@ -228,12 +254,14 @@ qqline(clouds_resid)
 ###################################################
 ### chunk number 26: MLR-clouds-cook eval=FALSE
 ###################################################
+## #line 550 "Ch_multiple_linear_regression.Rnw"
 ## plot(clouds_lm)
 
 
 ###################################################
 ### chunk number 27: MLR-clouds-cook
 ###################################################
+#line 553 "Ch_multiple_linear_regression.Rnw"
 plot(clouds_lm, which = 4, sub.caption = NULL)
 
 
