@@ -1,8 +1,10 @@
 ###################################################
 ### chunk number 1: setup
 ###################################################
+#line 184 "Ch_recursive_partitioning.Rnw"
 rm(list = ls())
 if (!file.exists("tables")) dir.create("tables")
+if (!file.exists("figures")) dir.create("figures")
 set.seed(290875)
 options(prompt = "R> ", continue = "+  ",
     width = 63, # digits = 4,
@@ -41,16 +43,20 @@ setHook(packageEvent("lattice", "attach"), function(...) {
 ###################################################
 ### chunk number 2: singlebook
 ###################################################
+#line 223 "Ch_recursive_partitioning.Rnw"
 book <- FALSE
 
 
 ###################################################
 ### chunk number 3: RP-setup
 ###################################################
+#line 226 "Ch_recursive_partitioning.Rnw"
 library("vcd")
 library("lattice")
 library("randomForest")
 library("party")
+if (!require("partykit"))
+    install.packages("partykit", repos = "http://R-forge.R-project.org")
 ltheme <- canonical.theme(color = FALSE) ## in-built B&W theme
 ltheme$strip.background$col <- "transparent" ## change strip bg
 lattice.options(default.theme = ltheme)
@@ -64,6 +70,7 @@ numbers <- c("zero", "one", "two", "three", "four", "five", "six", "seven", "eig
 ###################################################
 ### chunk number 4: RP-bodyfat-rpart
 ###################################################
+#line 253 "Ch_recursive_partitioning.Rnw"
 library("rpart")
 data("bodyfat", package = "mboost")
 bodyfat_rpart <- rpart(DEXfat ~ age + waistcirc + hipcirc +
@@ -71,9 +78,18 @@ bodyfat_rpart <- rpart(DEXfat ~ age + waistcirc + hipcirc +
     control = rpart.control(minsplit = 10))
 
 
+###################################################
+### chunk number 5: RP-bodyfat-plot
+###################################################
+#line 271 "Ch_recursive_partitioning.Rnw"
+library("partykit")
+plot(as.party(bodyfat_rpart), tp_args = list(id = FALSE))
+
+
 ###################################################
 ### chunk number 6: RP-bodyfat-cp
 ###################################################
+#line 283 "Ch_recursive_partitioning.Rnw"
 print(bodyfat_rpart$cptable)
 opt <- which.min(bodyfat_rpart$cptable[,"xerror"])
 
@@ -81,13 +97,22 @@ opt <- which.min(bodyfat_rpart$cptable[,"xerror"])
 ###################################################
 ### chunk number 7: RP-bodyfat-prune
 ###################################################
+#line 291 "Ch_recursive_partitioning.Rnw"
 cp <- bodyfat_rpart$cptable[opt, "CP"]
 bodyfat_prune <- prune(bodyfat_rpart, cp = cp)
 
 
+###################################################
+### chunk number 8: RP-bodyfat-pruneplot
+###################################################
+#line 300 "Ch_recursive_partitioning.Rnw"
+plot(as.party(bodyfat_prune), tp_args = list(id = FALSE))
+
+
 ###################################################
 ### chunk number 9: RP-bodyfat-predict
 ###################################################
+#line 315 "Ch_recursive_partitioning.Rnw"
 DEXfat_pred <- predict(bodyfat_prune, newdata = bodyfat)
 xlim <- range(bodyfat$DEXfat)
 plot(DEXfat_pred ~ DEXfat, data = bodyfat, xlab = "Observed",
@@ -98,12 +123,14 @@ abline(a = 0, b = 1)
 ###################################################
 ### chunk number 10: RP-seed-again
 ###################################################
+#line 327 "Ch_recursive_partitioning.Rnw"
 set.seed(290875)
 
 
 ###################################################
 ### chunk number 11: RP-glaucoma-rpart
 ###################################################
+#line 330 "Ch_recursive_partitioning.Rnw"
 data("GlaucomaM", package = "ipred")
 glaucoma_rpart <- rpart(Class ~ ., data = GlaucomaM,
     control = rpart.control(xval = 100))
@@ -113,9 +140,17 @@ cp <- glaucoma_rpart$cptable[opt, "CP"]
 glaucoma_prune <- prune(glaucoma_rpart, cp = cp)
 
 
+###################################################
+### chunk number 12: RP-glaucoma-plot
+###################################################
+#line 342 "Ch_recursive_partitioning.Rnw"
+plot(as.party(glaucoma_prune), tp_args = list(id = FALSE))
+
+
 ###################################################
 ### chunk number 13: RP-glaucoma-cp
 ###################################################
+#line 357 "Ch_recursive_partitioning.Rnw"
 nsplitopt <- vector(mode = "integer", length = 25)
 for (i in 1:length(nsplitopt)) {
     cp <- rpart(Class ~ ., data = GlaucomaM)$cptable
@@ -127,6 +162,7 @@ table(nsplitopt)
 ###################################################
 ### chunk number 14: RP-glaucoma-bagg
 ###################################################
+#line 378 "Ch_recursive_partitioning.Rnw"
 trees <- vector(mode = "list", length = 25)
 n <- nrow(GlaucomaM)
 bootsamples <- rmultinom(length(trees), n, rep(1, n)/n)
@@ -139,12 +175,14 @@ for (i in 1:length(trees))
 ###################################################
 ### chunk number 15: RP-glaucoma-splits
 ###################################################
+#line 393 "Ch_recursive_partitioning.Rnw"
 table(sapply(trees, function(x) as.character(x$frame$var[1])))
 
 
 ###################################################
 ### chunk number 16: RP-glaucoma-baggpred
 ###################################################
+#line 404 "Ch_recursive_partitioning.Rnw"
 classprob <- matrix(0, nrow = n, ncol = length(trees))
 for (i in 1:length(trees)) {
     classprob[,i] <- predict(trees[[i]],
@@ -156,6 +194,7 @@ for (i in 1:length(trees)) {
 ###################################################
 ### chunk number 17: RP-glaucoma-avg
 ###################################################
+#line 423 "Ch_recursive_partitioning.Rnw"
 avg <- rowMeans(classprob, na.rm = TRUE)
 predictions <- factor(ifelse(avg > 0.5, "glaucoma",
                                         "normal"))
@@ -166,18 +205,21 @@ predtab
 ###################################################
 ### chunk number 18: RP-glaucoma-sens
 ###################################################
+#line 432 "Ch_recursive_partitioning.Rnw"
 round(predtab[1,1] / colSums(predtab)[1] * 100)
 
 
 ###################################################
 ### chunk number 19: RP-glaucoma-spez
 ###################################################
+#line 436 "Ch_recursive_partitioning.Rnw"
 round(predtab[2,2] / colSums(predtab)[2] * 100)
 
 
 ###################################################
 ### chunk number 20: RP-glaucoma-baggplot
 ###################################################
+#line 443 "Ch_recursive_partitioning.Rnw"
 library("lattice")
 gdata <- data.frame(avg = rep(avg, 2),
     class = rep(as.numeric(GlaucomaM$Class), 2),
@@ -197,6 +239,7 @@ print(xyplot(avg ~ obs | var, data = gdata,
 ###################################################
 ### chunk number 21: RP-glaucoma-rf
 ###################################################
+#line 470 "Ch_recursive_partitioning.Rnw"
 library("randomForest")
 rf <- randomForest(Class ~ ., data = GlaucomaM)
 
@@ -204,12 +247,21 @@ rf <- randomForest(Class ~ ., data = GlaucomaM)
 ###################################################
 ### chunk number 22: RP-glaucoma-rf-oob
 ###################################################
+#line 475 "Ch_recursive_partitioning.Rnw"
 table(predict(rf), GlaucomaM$Class)
 
 
+###################################################
+### chunk number 23: RP-detach
+###################################################
+#line 479 "Ch_recursive_partitioning.Rnw"
+detach("package:partykit")
+
+
 ###################################################
 ### chunk number 24: RP-bodyfat-ctree
 ###################################################
+#line 486 "Ch_recursive_partitioning.Rnw"
 library("party")
 bodyfat_ctree <- ctree(DEXfat ~ age + waistcirc + hipcirc +
     elbowbreadth + kneebreadth, data = bodyfat)
@@ -218,18 +270,21 @@ bodyfat_ctree <- ctree(DEXfat ~ age + waistcirc + hipcirc +
 ###################################################
 ### chunk number 25: RP-bodyfat-ctree-plot
 ###################################################
+#line 499 "Ch_recursive_partitioning.Rnw"
 plot(bodyfat_ctree)
 
 
 ###################################################
 ### chunk number 26: RP-glaucoma-ctree
 ###################################################
+#line 508 "Ch_recursive_partitioning.Rnw"
 glaucoma_ctree <- ctree(Class ~ ., data = GlaucomaM)
 
 
 ###################################################
 ### chunk number 27: RP-glaucoma-ctree-plot
 ###################################################
+#line 518 "Ch_recursive_partitioning.Rnw"
 plot(glaucoma_ctree)
 
 
